==> ogre-14.3.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/manual.js <==
var manual =
[
    [ "Introduction", "_introduction.html", [
      [ "Object Orientation - more than just a buzzword", "_introduction.html#autotoc_md25", null ],
      [ "Multi-everything", "_introduction.html#autotoc_md26", null ]
    ] ],
    [ "The Core Objects", "_the-_core-_objects.html", [
      [ "Overview from 10,000 feet", "_the-_core-_objects.html#autotoc_md27", null ],
      [ "The Root object", "_the-_core-_objects.html#The-Root-Object", null ],
      [ "The RenderSystem object", "_the-_core-_objects.html#The-RenderSystem-object", null ],
      [ "The SceneManager object", "_the-_core-_objects.html#The-SceneManager-object", null ],
      [ "The ResourceGroupManager Object", "_the-_core-_objects.html#The-ResourceGroupManager-Object", null ],
      [ "The Mesh Object", "_the-_core-_objects.html#The-Mesh-Object", null ],
      [ "Entities", "_the-_core-_objects.html#Entities", null ],
      [ "Materials", "_the-_core-_objects.html#Materials", null ],
      [ "Overlays", "_the-_core-_objects.html#Overlays", [
        [ "How to Enable Overlays", "_the-_core-_objects.html#autotoc_md28", null ],
        [ "Creating 2D Elements", "_the-_core-_objects.html#autotoc_md29", null ],
        [ "Adding 2D Elements to the Overlay", "_the-_core-_objects.html#autotoc_md30", null ],
        [ "A word about 2D coordinates", "_the-_core-_objects.html#autotoc_md31", null ],
        [ "GUI systems", "_the-_core-_objects.html#autotoc_md33", null ]
      ] ]
    ] ],
    [ "Resource Management", "_resource-_management.html", [
      [ "Resource Life-cycle", "_resource-_management.html#Resource-Life-cycle", null ],
      [ "Locations", "_resource-_management.html#Resource-Location", null ],
      [ "Groups", "_resource-_management.html#Resource-Groups", [
        [ "Resource-Declaration", "_resource-_management.html#Resource-Declaration", null ]
      ] ]
    ] ],
    [ "Scripts", "_scripts.html", "_scripts" ],
    [ "Runtime Shader Generation", "rtss.html", [
      [ "RTSS Pass properties", "rtss.html#rtss_custom_mat", [
        [ "transform_stage", "rtss.html#autotoc_md244", null ],
        [ "lighting_stage", "rtss.html#autotoc_md245", null ],
        [ "image_based_lighting", "rtss.html#autotoc_md246", null ],
        [ "gbuffer", "rtss.html#autotoc_md247", null ],
        [ "normal_map", "rtss.html#autotoc_md248", null ],
        [ "metal_roughness", "rtss.html#autotoc_md249", null ],
        [ "fog_stage", "rtss.html#autotoc_md250", null ],
        [ "light_count", "rtss.html#autotoc_md251", null ],
        [ "triplanarTexturing", "rtss.html#autotoc_md252", null ],
        [ "integrated_pssm4", "rtss.html#autotoc_md253", null ],
        [ "shadow_mapping", "rtss.html#shadow_mapping", null ],
        [ "hardware_skinning", "rtss.html#autotoc_md254", null ]
      ] ],
      [ "RTSS Texture Unit properties", "rtss.html#rtss_tu_props", [
        [ "normal_map", "rtss.html#normal_map", null ],
        [ "layered_blend", "rtss.html#autotoc_md255", null ],
        [ "source_modifier", "rtss.html#autotoc_md256", null ]
      ] ],
      [ "Setting properties programmatically", "rtss.html#RTSS-Props-API", null ],
      [ "System overview", "rtss.html#rtss_overview", [
        [ "Core features of the system", "rtss.html#core-feats", null ],
        [ "Controlling shader re-generation", "rtss.html#autotoc_md257", null ]
      ] ],
      [ "The RTSS in Depth", "rtss.html#rtss_indepth", [
        [ "Main components", "rtss.html#rtss__components", null ],
        [ "Initializing the system", "rtss.html#autotoc_md258", null ],
        [ "Customizing the default RenderState", "rtss.html#rtss_custom_api", null ],
        [ "Creating the shader based technique", "rtss.html#rtssTech", null ],
        [ "Shader generation at runtime", "rtss.html#rtssGenerate", null ],
        [ "Creating custom shader extensions", "rtss.html#creating-extensions", null ],
        [ "Tips for debugging shaders", "rtss.html#debugging", null ]
      ] ]
    ] ],
    [ "Mesh Tools", "_mesh-_tools.html", [
      [ "XMLConverter", "_mesh-_tools.html#XMLConverter", null ],
      [ "MeshUpgrader", "_mesh-_tools.html#MeshUpgrader", null ],
      [ "AssimpConverter", "_mesh-_tools.html#AssimpConverter", null ],
      [ "Exporters", "_mesh-_tools.html#Exporters", [
        [ "Empty material names", "_mesh-_tools.html#empty-material-names", null ],
        [ "Skeletal animation", "_mesh-_tools.html#autotoc_md34", null ]
      ] ]
    ] ],
    [ "Hardware Buffers", "_hardware-_buffers.html", [
      [ "The Hardware Buffer Manager", "_hardware-_buffers.html#The-Hardware-Buffer-Manager", null ],
      [ "Buffer Usage", "_hardware-_buffers.html#Buffer-Usage", null ],
      [ "Shadow Buffers", "_hardware-_buffers.html#Shadow-Buffers", null ],
      [ "Data Transfer", "_hardware-_buffers.html#Data-Transfer", [
        [ "writeData and readData", "_hardware-_buffers.html#autotoc_md240", null ],
        [ "Locking buffers", "_hardware-_buffers.html#Locking-buffers", [
          [ "Lock parameters", "_hardware-_buffers.html#autotoc_md241", null ]
        ] ]
      ] ],
      [ "Practical Buffer Tips", "_hardware-_buffers.html#Practical-Buffer-Tips", [
        [ "Vulkan specific notes", "_hardware-_buffers.html#autotoc_md242", null ]
      ] ],
      [ "Hardware Vertex Buffers", "_hardware-_buffers.html#Hardware-Vertex-Buffers", [
        [ "The VertexData class", "_hardware-_buffers.html#The-VertexData-class", null ],
        [ "Vertex Declarations", "_hardware-_buffers.html#Vertex-Declarations", null ],
        [ "Vertex Buffer Bindings", "_hardware-_buffers.html#Vertex-Buffer-Bindings", null ],
        [ "Creating the Vertex Buffer", "_hardware-_buffers.html#Creating-the-Vertex-Buffer", null ],
        [ "Binding the Vertex Buffer", "_hardware-_buffers.html#Binding-the-Vertex-Buffer", null ],
        [ "Updating Vertex Buffers", "_hardware-_buffers.html#Updating-Vertex-Buffers", null ]
      ] ],
      [ "Hardware Index Buffers", "_hardware-_buffers.html#Hardware-Index-Buffers", [
        [ "The IndexData class", "_hardware-_buffers.html#The-IndexData-class", null ],
        [ "Creating an Index Buffer", "_hardware-_buffers.html#autotoc_md243", null ],
        [ "Updating Index Buffers", "_hardware-_buffers.html#Updating-Index-Buffers", null ]
      ] ],
      [ "Hardware Pixel Buffers", "_hardware-_buffers.html#Hardware-Pixel-Buffers", [
        [ "Pixel boxes", "_hardware-_buffers.html#Pixel-boxes", null ],
        [ "Updating Pixel Buffers", "_hardware-_buffers.html#Updating-Pixel-Buffers", [
          [ "Blit from memory", "_hardware-_buffers.html#blitFromMemory", null ],
          [ "Direct memory locking", "_hardware-_buffers.html#Direct-memory-locking", null ]
        ] ]
      ] ],
      [ "Textures", "_hardware-_buffers.html#Textures", [
        [ "Creating a texture", "_hardware-_buffers.html#Creating-a-texture", null ],
        [ "Getting a PixelBuffer", "_hardware-_buffers.html#Getting-a-PixelBuffer", null ],
        [ "Cube map textures", "_hardware-_buffers.html#Cube-map-textures", null ],
        [ "Pixel Formats", "_hardware-_buffers.html#Pixel-Formats", [
          [ "Colour channels", "_hardware-_buffers.html#Colour-channels", null ]
        ] ]
      ] ]
    ] ],
    [ "Shadows", "_shadows.html", [
      [ "Enabling shadows", "_shadows.html#Enabling-shadows", null ],
      [ "Opting out of shadows", "_shadows.html#Opting-out-of-shadows", null ],
      [ "Stencil Shadows", "_shadows.html#Stencil-Shadows", [
        [ "CPU Overhead", "_shadows.html#autotoc_md35", null ],
        [ "Extrusion distance", "_shadows.html#autotoc_md36", null ],
        [ "Camera far plane positioning", "_shadows.html#autotoc_md37", null ],
        [ "Mesh edge lists", "_shadows.html#autotoc_md38", null ],
        [ "The Silhouette Edge", "_shadows.html#autotoc_md39", null ],
        [ "Be realistic", "_shadows.html#autotoc_md40", null ],
        [ "Stencil optimisations performed by Ogre", "_shadows.html#autotoc_md41", null ]
      ] ],
      [ "Texture-based Shadows", "_shadows.html#Texture_002dbased-Shadows", [
        [ "Directional Lights", "_shadows.html#autotoc_md42", null ],
        [ "Spotlights", "_shadows.html#autotoc_md43", null ],
        [ "Point Lights", "_shadows.html#autotoc_md44", null ],
        [ "Shadow Casters and Shadow Receivers", "_shadows.html#autotoc_md45", null ]
      ] ],
      [ "Configuring Texture Shadows", "_shadows.html#Configuring-Texture-Shadows", [
        [ "Maximum number of shadow textures", "_shadows.html#autotoc_md46", null ],
        [ "Shadow texture size", "_shadows.html#autotoc_md47", null ],
        [ "Shadow far distance", "_shadows.html#autotoc_md48", null ],
        [ "Shadow texture offset (Directional Lights)", "_shadows.html#autotoc_md49", null ],
        [ "Shadow fade settings", "_shadows.html#autotoc_md50", null ]
      ] ],
      [ "Texture shadows and vertex / fragment programs", "_shadows.html#texture_shadows_and_shaders", [
        [ "Custom shadow camera setups", "_shadows.html#autotoc_md51", null ],
        [ "Shadow texture Depth Buffer sharing", "_shadows.html#autotoc_md52", null ],
        [ "Integrated Texture Shadows", "_shadows.html#Integrated-Texture-Shadows", null ]
      ] ],
      [ "Modulative Shadows", "_shadows.html#Modulative-Shadows", [
        [ "Shadow Colour", "_shadows.html#autotoc_md53", null ]
      ] ],
      [ "Additive Light Masking", "_shadows.html#Additive-Light-Masking", [
        [ "Manually Categorising Illumination Passes", "_shadows.html#Manually-Categorising-Illumination-Passes", null ],
        [ "Pass Classification and Vertex Programs", "_shadows.html#Pass-Classification-and-Vertex-Programs", null ],
        [ "Static Lighting", "_shadows.html#Static-Lighting", null ]
      ] ]
    ] ],
    [ "Animation", "_animation.html", [
      [ "Animation State", "_animation.html#Animation-State", null ],
      [ "Skeletal Animation", "_animation.html#Skeletal-Animation", null ],
      [ "SceneNode Animation", "_animation.html#SceneNode-Animation", null ],
      [ "Vertex Animation", "_animation.html#Vertex-Animation", [
        [ "Why two subtypes?", "_animation.html#autotoc_md54", null ],
        [ "Subtype applies per track", "_animation.html#autotoc_md55", null ],
        [ "Vertex buffer arrangements", "_animation.html#autotoc_md56", null ],
        [ "Morph Animation", "_animation.html#Morph-Animation", null ],
        [ "Pose Animation", "_animation.html#Pose-Animation", null ],
        [ "Combining Skeletal and Vertex Animation", "_animation.html#Combining-Skeletal-and-Vertex-Animation", [
          [ "Combined Hardware Skinning", "_animation.html#Combined-Hardware-Skinning", null ],
          [ "Submesh Splits", "_animation.html#Submesh-Splits", null ]
        ] ]
      ] ],
      [ "Numeric Value Animation", "_animation.html#Numeric-Value-Animation", [
        [ "AnimableObject", "_animation.html#autotoc_md57", null ],
        [ "AnimableValue", "_animation.html#autotoc_md58", null ]
      ] ]
    ] ],
    [ "Instancing", "_instancing.html", "_instancing" ],
    [ "Cross-platform Shaders", "_cross-platform-_shaders.html", [
      [ "Built-in defines", "_cross-platform-_shaders.html#autotoc_md204", null ],
      [ "Cross-platform macros", "_cross-platform-_shaders.html#OgreUnifiedShader", null ],
      [ "Uber shader tips", "_cross-platform-_shaders.html#autotoc_md205", null ]
    ] ]
];

==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/manual.js <==
var manual =
[
    [ "Introduction", "_introduction.html", [
      [ "Object Orientation - more than just a buzzword", "_introduction.html#autotoc_md25", null ],
      [ "Multi-everything", "_introduction.html#autotoc_md26", null ]
    ] ],
    [ "The Core Objects", "_the-_core-_objects.html", [
      [ "Overview from 10,000 feet", "_the-_core-_objects.html#autotoc_md27", null ],
      [ "The Root object", "_the-_core-_objects.html#The-Root-Object", null ],
      [ "The RenderSystem object", "_the-_core-_objects.html#The-RenderSystem-object", null ],
      [ "The SceneManager object", "_the-_core-_objects.html#The-SceneManager-object", null ],
      [ "The ResourceGroupManager Object", "_the-_core-_objects.html#The-ResourceGroupManager-Object", null ],
      [ "The Mesh Object", "_the-_core-_objects.html#The-Mesh-Object", null ],
      [ "Entities", "_the-_core-_objects.html#Entities", null ],
      [ "Materials", "_the-_core-_objects.html#Materials", [
        [ "Managing", "_the-_core-_objects.html#Materials-Manage", null ],
        [ "Structure", "_the-_core-_objects.html#Materials-Structure", null ]
      ] ],
      [ "Overlays", "_the-_core-_objects.html#Overlays", [
        [ "How to Enable Overlays", "_the-_core-_objects.html#autotoc_md28", null ],
        [ "Creating 2D Elements", "_the-_core-_objects.html#autotoc_md29", null ],
        [ "Adding 2D Elements to the Overlay", "_the-_core-_objects.html#autotoc_md30", null ],
        [ "A word about 2D coordinates", "_the-_core-_objects.html#autotoc_md31", null ],
        [ "GUI systems", "_the-_core-_objects.html#autotoc_md33", null ]
      ] ]
    ] ],
    [ "Resource Management", "_resource-_management.html", [
      [ "Resource Life-cycle", "_resource-_management.html#Resource-Life-cycle", null ],
      [ "Locations", "_resource-_management.html#Resource-Location", null ],
      [ "Groups", "_resource-_management.html#Resource-Groups", [
        [ "Resource-Declaration", "_resource-_management.html#Resource-Declaration", null ]
      ] ]
    ] ],
    [ "Scripts", "_scripts.html", "_scripts" ],
    [ "Runtime Shader Generation", "rtss.html", [
      [ "RTSS Pass properties", "rtss.html#rtss_custom_mat", [
        [ "transform_stage", "rtss.html#autotoc_md244", null ],
        [ "lighting_stage", "rtss.html#autotoc_md245", null ],
        [ "image_based_lighting", "rtss.html#autotoc_md246", null ],
        [ "gbuffer", "rtss.html#autotoc_md247", null ],
        [ "normal_map", "rtss.html#autotoc_md248", null ],
        [ "metal_roughness", "rtss.html#autotoc_md249", null ],
        [ "fog_stage", "rtss.html#autotoc_md250", null ],
        [ "light_count", "rtss.html#autotoc_md251", null ],
        [ "triplanarTexturing", "rtss.html#autotoc_md252", null ],
        [ "integrated_pssm4", "rtss.html#autotoc_md253", null ],
        [ "shadow_mapping", "rtss.html#shadow_mapping", null ],
        [ "hardware_skinning", "rtss.html#autotoc_md254", null ]
      ] ],
      [ "RTSS Texture Unit properties", "rtss.html#rtss_tu_props", [
        [ "normal_map", "rtss.html#normal_map", null ],
        [ "layered_blend", "rtss.html#autotoc_md255", null ],
        [ "source_modifier", "rtss.html#autotoc_md256", null ]
      ] ],
      [ "Setting properties programmatically", "rtss.html#RTSS-Props-API", null ],
      [ "System overview", "rtss.html#rtss_overview", [
        [ "Core features of the system", "rtss.html#core-feats", null ],
        [ "Controlling shader re-generation", "rtss.html#autotoc_md257", null ]
      ] ],
      [ "The RTSS in Depth", "rtss.html#rtss_indepth", [
        [ "Main components", "rtss.html#rtss__components", null ],
        [ "Initializing the system", "rtss.html#autotoc_md258", null ],
        [ "Customizing the default RenderState", "rtss.html#rtss_custom_api", null ],
        [ "Creating the shader based technique", "rtss.html#rtssTech", null ],
        [ "Shader generation at runtime", "rtss.html#rtssGenerate", null ],
        [ "Creating custom shader extensions", "rtss.html#creating-extensions", null ],
        [ "Tips for debugging shaders", "rtss.html#debugging", null ]
      ] ]
    ] ],
    [ "Mesh Tools", "_mesh-_tools.html", [
      [ "XMLConverter", "_mesh-_tools.html#XMLConverter", null ],
      [ "MeshUpgrader", "_mesh-_tools.html#MeshUpgrader", null ],
      [ "AssimpConverter", "_mesh-_tools.html#AssimpConverter", null ],
      [ "Exporters", "_mesh-_tools.html#Exporters", [
        [ "Empty material names", "_mesh-_tools.html#empty-material-names", null ],
        [ "Skeletal animation", "_mesh-_tools.html#autotoc_md34", null ]
      ] ]
    ] ],
    [ "Hardware Buffers", "_hardware-_buffers.html", [
      [ "The Hardware Buffer Manager", "_hardware-_buffers.html#The-Hardware-Buffer-Manager", null ],
      [ "Buffer Usage", "_hardware-_buffers.html#Buffer-Usage", null ],
      [ "Shadow Buffers", "_hardware-_buffers.html#Shadow-Buffers", null ],
      [ "Data Transfer", "_hardware-_buffers.html#Data-Transfer", [
        [ "writeData and readData", "_hardware-_buffers.html#autotoc_md240", null ],
        [ "Locking buffers", "_hardware-_buffers.html#Locking-buffers", [
          [ "Lock parameters", "_hardware-_buffers.html#autotoc_md241", null ]
        ] ]
      ] ],
      [ "Practical Buffer Tips", "_hardware-_buffers.html#Practical-Buffer-Tips", [
        [ "Vulkan specific notes", "_hardware-_buffers.html#autotoc_md242", null ]
      ] ],
      [ "Hardware Vertex Buffers", "_hardware-_buffers.html#Hardware-Vertex-Buffers", [
        [ "The VertexData class", "_hardware-_buffers.html#The-VertexData-class", null ],
        [ "Vertex Declarations", "_hardware-_buffers.html#Vertex-Declarations", null ],
        [ "Vertex Buffer Bindings", "_hardware-_buffers.html#Vertex-Buffer-Bindings", null ],
        [ "Creating the Vertex Buffer", "_hardware-_buffers.html#Creating-the-Vertex-Buffer", null ],
        [ "Binding the Vertex Buffer", "_hardware-_buffers.html#Binding-the-Vertex-Buffer", null ],
        [ "Updating Vertex Buffers", "_hardware-_buffers.html#Updating-Vertex-Buffers", null ]
      ] ],
      [ "Hardware Index Buffers", "_hardware-_buffers.html#Hardware-Index-Buffers", [
        [ "The IndexData class", "_hardware-_buffers.html#The-IndexData-class", null ],
        [ "Creating an Index Buffer", "_hardware-_buffers.html#autotoc_md243", null ],
        [ "Updating Index Buffers", "_hardware-_buffers.html#Updating-Index-Buffers", null ]
      ] ],
      [ "Hardware Pixel Buffers", "_hardware-_buffers.html#Hardware-Pixel-Buffers", [
        [ "Pixel boxes", "_hardware-_buffers.html#Pixel-boxes", null ],
        [ "Updating Pixel Buffers", "_hardware-_buffers.html#Updating-Pixel-Buffers", [
          [ "Blit from memory", "_hardware-_buffers.html#blitFromMemory", null ],
          [ "Direct memory locking", "_hardware-_buffers.html#Direct-memory-locking", null ]
        ] ]
      ] ],
      [ "Textures", "_hardware-_buffers.html#Textures", [
        [ "Creating a texture", "_hardware-_buffers.html#Creating-a-texture", null ],
        [ "Getting a PixelBuffer", "_hardware-_buffers.html#Getting-a-PixelBuffer", null ],
        [ "Cube map textures", "_hardware-_buffers.html#Cube-map-textures", null ],
        [ "Pixel Formats", "_hardware-_buffers.html#Pixel-Formats", [
          [ "Colour channels", "_hardware-_buffers.html#Colour-channels", null ]
        ] ]
      ] ]
    ] ],
    [ "Shadows", "_shadows.html", [
      [ "Enabling shadows", "_shadows.html#Enabling-shadows", null ],
      [ "Opting out of shadows", "_shadows.html#Opting-out-of-shadows", null ],
      [ "Stencil Shadows", "_shadows.html#Stencil-Shadows", [
        [ "CPU Overhead", "_shadows.html#autotoc_md35", null ],
        [ "Extrusion distance", "_shadows.html#autotoc_md36", null ],
        [ "Camera far plane positioning", "_shadows.html#autotoc_md37", null ],
        [ "Mesh edge lists", "_shadows.html#autotoc_md38", null ],
        [ "The Silhouette Edge", "_shadows.html#autotoc_md39", null ],
        [ "Be realistic", "_shadows.html#autotoc_md40", null ],
        [ "Stencil optimisations performed by Ogre", "_shadows.html#autotoc_md41", null ]
      ] ],
      [ "Texture-based Shadows", "_shadows.html#Texture_002dbased-Shadows", [
        [ "Directional Lights", "_shadows.html#autotoc_md42", null ],
        [ "Spotlights", "_shadows.html#autotoc_md43", null ],
        [ "Point Lights", "_shadows.html#autotoc_md44", null ],
        [ "Shadow Casters and Shadow Receivers", "_shadows.html#autotoc_md45", null ]
      ] ],
      [ "Configuring Texture Shadows", "_shadows.html#Configuring-Texture-Shadows", [
        [ "Maximum number of shadow textures", "_shadows.html#autotoc_md46", null ],
        [ "Shadow texture size", "_shadows.html#autotoc_md47", null ],
        [ "Shadow far distance", "_shadows.html#autotoc_md48", null ],
        [ "Shadow texture offset (Directional Lights)", "_shadows.html#autotoc_md49", null ],
        [ "Shadow fade settings", "_shadows.html#autotoc_md50", null ]
      ] ],
      [ "Texture shadows and vertex / fragment programs", "_shadows.html#texture_shadows_and_shaders", [
        [ "Custom shadow camera setups", "_shadows.html#autotoc_md51", null ],
        [ "Shadow texture Depth Buffer sharing", "_shadows.html#autotoc_md52", null ],
        [ "Integrated Texture Shadows", "_shadows.html#Integrated-Texture-Shadows", null ]
      ] ],
      [ "Modulative Shadows", "_shadows.html#Modulative-Shadows", [
        [ "Shadow Colour", "_shadows.html#autotoc_md53", null ]
      ] ],
      [ "Additive Light Masking", "_shadows.html#Additive-Light-Masking", [
        [ "Manually Categorising Illumination Passes", "_shadows.html#Manually-Categorising-Illumination-Passes", null ],
        [ "Pass Classification and Vertex Programs", "_shadows.html#Pass-Classification-and-Vertex-Programs", null ],
        [ "Static Lighting", "_shadows.html#Static-Lighting", null ]
      ] ]
    ] ],
    [ "Animation", "_animation.html", [
      [ "Animation State", "_animation.html#Animation-State", null ],
      [ "Skeletal Animation", "_animation.html#Skeletal-Animation", null ],
      [ "SceneNode Animation", "_animation.html#SceneNode-Animation", null ],
      [ "Vertex Animation", "_animation.html#Vertex-Animation", [
        [ "Why two subtypes?", "_animation.html#autotoc_md54", null ],
        [ "Subtype applies per track", "_animation.html#autotoc_md55", null ],
        [ "Vertex buffer arrangements", "_animation.html#autotoc_md56", null ],
        [ "Morph Animation", "_animation.html#Morph-Animation", null ],
        [ "Pose Animation", "_animation.html#Pose-Animation", null ],
        [ "Combining Skeletal and Vertex Animation", "_animation.html#Combining-Skeletal-and-Vertex-Animation", [
          [ "Combined Hardware Skinning", "_animation.html#Combined-Hardware-Skinning", null ],
          [ "Submesh Splits", "_animation.html#Submesh-Splits", null ]
        ] ]
      ] ],
      [ "Numeric Value Animation", "_animation.html#Numeric-Value-Animation", [
        [ "AnimableObject", "_animation.html#autotoc_md57", null ],
        [ "AnimableValue", "_animation.html#autotoc_md58", null ]
      ] ]
    ] ],
    [ "Instancing", "_instancing.html", "_instancing" ],
    [ "Cross-platform Shaders", "_cross-platform-_shaders.html", [
      [ "Built-in defines", "_cross-platform-_shaders.html#autotoc_md204", null ],
      [ "Cross-platform macros", "_cross-platform-_shaders.html#OgreUnifiedShader", null ],
      [ "Uber shader tips", "_cross-platform-_shaders.html#autotoc_md205", null ]
    ] ]
];
